pub enum MinecraftAuthorizationError<E: Error> {
Http(E),
HttpStatus(StatusCode),
Json(Error),
AddToFamily,
NoXbox,
MissingClaims,
XboxLive {
code: u32,
},
}Expand description
Represents an error that can occur when authenticating with Minecraft.
Variants
Http(E)
An error occurred while executing the HTTP request
HttpStatus(StatusCode)
The server responded with a non-success status code
Json(Error)
An error occurred while serializing or deserializing JSON
AddToFamily
Account belongs to a minor who needs to be added to a microsoft family
NoXbox
Account does not have xbox, user must create an xbox account to continue
MissingClaims
Claims were missing from the response
XboxLive
Xbox Live rejected authentication with an unrecognized error code