pub struct MinecraftAuthenticationResponse { /* private fields */ }Expand description
The response from Minecraft when attempting to authenticate with an xbox token
Implementations
Sourceimpl MinecraftAuthenticationResponse
impl MinecraftAuthenticationResponse
Sourcepub fn username(&self) -> &String
pub fn username(&self) -> &String
UUID of the Xbox account. Please note that this is not the Minecraft player’s UUID
Sourcepub fn access_token(&self) -> &MinecraftAccessToken
pub fn access_token(&self) -> &MinecraftAccessToken
The minecraft JWT access token
Sourcepub fn token_type(&self) -> &MinecraftTokenType
pub fn token_type(&self) -> &MinecraftTokenType
The type of access token
Sourceimpl MinecraftAuthenticationResponse
impl MinecraftAuthenticationResponse
Sourcepub fn expires_in(&self) -> u32
pub fn expires_in(&self) -> u32
How many seconds until the token expires