pub struct MinecraftAuthorizationFlow<C> { /* private fields */ }Expand description
The flow for authenticating with a Microsoft access token and getting a Minecraft access token.
Implementations
Sourceimpl<C> MinecraftAuthorizationFlow<C>
impl<C> MinecraftAuthorizationFlow<C>
Sourcepub const fn new(http_client: C) -> Self
pub const fn new(http_client: C) -> Self
Creates a new MinecraftAuthorizationFlow using the given HttpClient.
Sourceimpl<C: HttpClient> MinecraftAuthorizationFlow<C>
impl<C: HttpClient> MinecraftAuthorizationFlow<C>
Sourcepub async fn exchange_microsoft_token(
&self,
microsoft_access_token: impl AsRef<str>,
) -> Result<MinecraftAuthenticationResponse, MinecraftAuthorizationError<C::Error>>
pub async fn exchange_microsoft_token( &self, microsoft_access_token: impl AsRef<str>, ) -> Result<MinecraftAuthenticationResponse, MinecraftAuthorizationError<C::Error>>
Authenticates with the Microsoft identity platform using the given Microsoft access token and returns a MinecraftAuthenticationResponse that contains the Minecraft access token.